# Generated by Django 2.2.2 on 2019-06-09 18:38

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0039_auto_20190609_1837'),
    ]

    operations = [
        migrations.AlterField(
            model_name='document_attributes',
            name='attr_type_real',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, related_name='attr_type_real_name', to='ckk.Attr_type', verbose_name='Тип атрибута'),
        ),
    ]
