# Generated by Django 2.2.2 on 2019-06-06 18:39

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0033_auto_20190606_1839'),
        ('ckk', '0077_delete_item_production_specificationview'),
    ]

    operations = [
        migrations.CreateModel(
            name='Item_production_specificationView',
            fields=[
                ('id', models.BigAutoField(primary_key=True, serialize=False, verbose_name='Идентификатор')),
                ('id_old', models.BigIntegerField(blank=True, null=True, verbose_name='Идентификатор старый')),
                ('deleted_at', models.DateTimeField(blank=True, db_index=True, null=True, verbose_name='Дата мягкого удаления')),
                ('editing', models.BooleanField(default=True, verbose_name='Возможность редактирования')),
                ('deliting', models.BooleanField(default=True, verbose_name='Возможность удаления')),
                ('lastmodified', models.DateTimeField(db_index=True, default=django.utils.timezone.now, editable=False, verbose_name='Последнее обновление')),
                ('STMP_1', models.TextField(blank=True, null=True)),
                ('STMP_2', models.TextField(blank=True, null=True)),
            ],
            options={
                'verbose_name': 'Производственная спецификация',
                'db_table': 'ckk_item_production_specification_view',
                'managed': False,
            },
        ),
        migrations.AlterUniqueTogether(
            name='item_line',
            unique_together={('parent', 'child'), ('SPC_CLM_MARK', 'SPC_CLM_NAME')},
        ),
    ]
